# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ProcessRunMetricsProcessStatistics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'current_cpu': 'float',
        'average_cpu': 'float',
        'current_virtual_memory': 'float',
        'current_working_set': 'float',
        'metrics': 'list[ProcessRunMetricsProcessMetricPoint]'
    }

    attribute_map = {
        'current_cpu': 'CurrentCpu',
        'average_cpu': 'AverageCpu',
        'current_virtual_memory': 'CurrentVirtualMemory',
        'current_working_set': 'CurrentWorkingSet',
        'metrics': 'Metrics'
    }

    def __init__(self, current_cpu=None, average_cpu=None, current_virtual_memory=None, current_working_set=None, metrics=None):  # noqa: E501
        """ProcessRunMetricsProcessStatistics - a model defined in Swagger"""  # noqa: E501
        self._current_cpu = None
        self._average_cpu = None
        self._current_virtual_memory = None
        self._current_working_set = None
        self._metrics = None
        self.discriminator = None
        if current_cpu is not None:
            self.current_cpu = current_cpu
        if average_cpu is not None:
            self.average_cpu = average_cpu
        if current_virtual_memory is not None:
            self.current_virtual_memory = current_virtual_memory
        if current_working_set is not None:
            self.current_working_set = current_working_set
        if metrics is not None:
            self.metrics = metrics

    @property
    def current_cpu(self):
        """Gets the current_cpu of this ProcessRunMetricsProcessStatistics.  # noqa: E501

        The current cpu.  # noqa: E501

        :return: The current_cpu of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :rtype: float
        """
        return self._current_cpu

    @current_cpu.setter
    def current_cpu(self, current_cpu):
        """Sets the current_cpu of this ProcessRunMetricsProcessStatistics.

        The current cpu.  # noqa: E501

        :param current_cpu: The current_cpu of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :type: float
        """

        self._current_cpu = current_cpu

    @property
    def average_cpu(self):
        """Gets the average_cpu of this ProcessRunMetricsProcessStatistics.  # noqa: E501

        The average cpu.  # noqa: E501

        :return: The average_cpu of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :rtype: float
        """
        return self._average_cpu

    @average_cpu.setter
    def average_cpu(self, average_cpu):
        """Sets the average_cpu of this ProcessRunMetricsProcessStatistics.

        The average cpu.  # noqa: E501

        :param average_cpu: The average_cpu of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :type: float
        """

        self._average_cpu = average_cpu

    @property
    def current_virtual_memory(self):
        """Gets the current_virtual_memory of this ProcessRunMetricsProcessStatistics.  # noqa: E501

        The currently allocated virtual memory.  # noqa: E501

        :return: The current_virtual_memory of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :rtype: float
        """
        return self._current_virtual_memory

    @current_virtual_memory.setter
    def current_virtual_memory(self, current_virtual_memory):
        """Sets the current_virtual_memory of this ProcessRunMetricsProcessStatistics.

        The currently allocated virtual memory.  # noqa: E501

        :param current_virtual_memory: The current_virtual_memory of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :type: float
        """

        self._current_virtual_memory = current_virtual_memory

    @property
    def current_working_set(self):
        """Gets the current_working_set of this ProcessRunMetricsProcessStatistics.  # noqa: E501

        The currently allocated working set.  # noqa: E501

        :return: The current_working_set of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :rtype: float
        """
        return self._current_working_set

    @current_working_set.setter
    def current_working_set(self, current_working_set):
        """Sets the current_working_set of this ProcessRunMetricsProcessStatistics.

        The currently allocated working set.  # noqa: E501

        :param current_working_set: The current_working_set of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :type: float
        """

        self._current_working_set = current_working_set

    @property
    def metrics(self):
        """Gets the metrics of this ProcessRunMetricsProcessStatistics.  # noqa: E501

        The metrics.  # noqa: E501

        :return: The metrics of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :rtype: list[ProcessRunMetricsProcessMetricPoint]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this ProcessRunMetricsProcessStatistics.

        The metrics.  # noqa: E501

        :param metrics: The metrics of this ProcessRunMetricsProcessStatistics.  # noqa: E501
        :type: list[ProcessRunMetricsProcessMetricPoint]
        """

        self._metrics = metrics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProcessRunMetricsProcessStatistics, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessRunMetricsProcessStatistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UserConfiguration(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'audio_language_preference': 'str',
        'play_default_audio_track': 'bool',
        'subtitle_language_preference': 'str',
        'profile_pin': 'str',
        'display_missing_episodes': 'bool',
        'subtitle_mode': 'SubtitlePlaybackMode',
        'ordered_views': 'list[str]',
        'latest_items_excludes': 'list[str]',
        'my_media_excludes': 'list[str]',
        'hide_played_in_latest': 'bool',
        'hide_played_in_more_like_this': 'bool',
        'hide_played_in_suggestions': 'bool',
        'remember_audio_selections': 'bool',
        'remember_subtitle_selections': 'bool',
        'enable_next_episode_auto_play': 'bool',
        'resume_rewind_seconds': 'int',
        'intro_skip_mode': 'SegmentSkipMode',
        'enable_local_password': 'bool'
    }

    attribute_map = {
        'audio_language_preference': 'AudioLanguagePreference',
        'play_default_audio_track': 'PlayDefaultAudioTrack',
        'subtitle_language_preference': 'SubtitleLanguagePreference',
        'profile_pin': 'ProfilePin',
        'display_missing_episodes': 'DisplayMissingEpisodes',
        'subtitle_mode': 'SubtitleMode',
        'ordered_views': 'OrderedViews',
        'latest_items_excludes': 'LatestItemsExcludes',
        'my_media_excludes': 'MyMediaExcludes',
        'hide_played_in_latest': 'HidePlayedInLatest',
        'hide_played_in_more_like_this': 'HidePlayedInMoreLikeThis',
        'hide_played_in_suggestions': 'HidePlayedInSuggestions',
        'remember_audio_selections': 'RememberAudioSelections',
        'remember_subtitle_selections': 'RememberSubtitleSelections',
        'enable_next_episode_auto_play': 'EnableNextEpisodeAutoPlay',
        'resume_rewind_seconds': 'ResumeRewindSeconds',
        'intro_skip_mode': 'IntroSkipMode',
        'enable_local_password': 'EnableLocalPassword'
    }

    def __init__(self, audio_language_preference=None, play_default_audio_track=None, subtitle_language_preference=None, profile_pin=None, display_missing_episodes=None, subtitle_mode=None, ordered_views=None, latest_items_excludes=None, my_media_excludes=None, hide_played_in_latest=None, hide_played_in_more_like_this=None, hide_played_in_suggestions=None, remember_audio_selections=None, remember_subtitle_selections=None, enable_next_episode_auto_play=None, resume_rewind_seconds=None, intro_skip_mode=None, enable_local_password=None):  # noqa: E501
        """UserConfiguration - a model defined in Swagger"""  # noqa: E501
        self._audio_language_preference = None
        self._play_default_audio_track = None
        self._subtitle_language_preference = None
        self._profile_pin = None
        self._display_missing_episodes = None
        self._subtitle_mode = None
        self._ordered_views = None
        self._latest_items_excludes = None
        self._my_media_excludes = None
        self._hide_played_in_latest = None
        self._hide_played_in_more_like_this = None
        self._hide_played_in_suggestions = None
        self._remember_audio_selections = None
        self._remember_subtitle_selections = None
        self._enable_next_episode_auto_play = None
        self._resume_rewind_seconds = None
        self._intro_skip_mode = None
        self._enable_local_password = None
        self.discriminator = None
        if audio_language_preference is not None:
            self.audio_language_preference = audio_language_preference
        if play_default_audio_track is not None:
            self.play_default_audio_track = play_default_audio_track
        if subtitle_language_preference is not None:
            self.subtitle_language_preference = subtitle_language_preference
        if profile_pin is not None:
            self.profile_pin = profile_pin
        if display_missing_episodes is not None:
            self.display_missing_episodes = display_missing_episodes
        if subtitle_mode is not None:
            self.subtitle_mode = subtitle_mode
        if ordered_views is not None:
            self.ordered_views = ordered_views
        if latest_items_excludes is not None:
            self.latest_items_excludes = latest_items_excludes
        if my_media_excludes is not None:
            self.my_media_excludes = my_media_excludes
        if hide_played_in_latest is not None:
            self.hide_played_in_latest = hide_played_in_latest
        if hide_played_in_more_like_this is not None:
            self.hide_played_in_more_like_this = hide_played_in_more_like_this
        if hide_played_in_suggestions is not None:
            self.hide_played_in_suggestions = hide_played_in_suggestions
        if remember_audio_selections is not None:
            self.remember_audio_selections = remember_audio_selections
        if remember_subtitle_selections is not None:
            self.remember_subtitle_selections = remember_subtitle_selections
        if enable_next_episode_auto_play is not None:
            self.enable_next_episode_auto_play = enable_next_episode_auto_play
        if resume_rewind_seconds is not None:
            self.resume_rewind_seconds = resume_rewind_seconds
        if intro_skip_mode is not None:
            self.intro_skip_mode = intro_skip_mode
        if enable_local_password is not None:
            self.enable_local_password = enable_local_password

    @property
    def audio_language_preference(self):
        """Gets the audio_language_preference of this UserConfiguration.  # noqa: E501

        The audio language preference.  # noqa: E501

        :return: The audio_language_preference of this UserConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._audio_language_preference

    @audio_language_preference.setter
    def audio_language_preference(self, audio_language_preference):
        """Sets the audio_language_preference of this UserConfiguration.

        The audio language preference.  # noqa: E501

        :param audio_language_preference: The audio_language_preference of this UserConfiguration.  # noqa: E501
        :type: str
        """

        self._audio_language_preference = audio_language_preference

    @property
    def play_default_audio_track(self):
        """Gets the play_default_audio_track of this UserConfiguration.  # noqa: E501

        A value indicating whether \\[play default audio track\\].  # noqa: E501

        :return: The play_default_audio_track of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._play_default_audio_track

    @play_default_audio_track.setter
    def play_default_audio_track(self, play_default_audio_track):
        """Sets the play_default_audio_track of this UserConfiguration.

        A value indicating whether \\[play default audio track\\].  # noqa: E501

        :param play_default_audio_track: The play_default_audio_track of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._play_default_audio_track = play_default_audio_track

    @property
    def subtitle_language_preference(self):
        """Gets the subtitle_language_preference of this UserConfiguration.  # noqa: E501

        The subtitle language preference.  # noqa: E501

        :return: The subtitle_language_preference of this UserConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._subtitle_language_preference

    @subtitle_language_preference.setter
    def subtitle_language_preference(self, subtitle_language_preference):
        """Sets the subtitle_language_preference of this UserConfiguration.

        The subtitle language preference.  # noqa: E501

        :param subtitle_language_preference: The subtitle_language_preference of this UserConfiguration.  # noqa: E501
        :type: str
        """

        self._subtitle_language_preference = subtitle_language_preference

    @property
    def profile_pin(self):
        """Gets the profile_pin of this UserConfiguration.  # noqa: E501


        :return: The profile_pin of this UserConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._profile_pin

    @profile_pin.setter
    def profile_pin(self, profile_pin):
        """Sets the profile_pin of this UserConfiguration.


        :param profile_pin: The profile_pin of this UserConfiguration.  # noqa: E501
        :type: str
        """

        self._profile_pin = profile_pin

    @property
    def display_missing_episodes(self):
        """Gets the display_missing_episodes of this UserConfiguration.  # noqa: E501


        :return: The display_missing_episodes of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._display_missing_episodes

    @display_missing_episodes.setter
    def display_missing_episodes(self, display_missing_episodes):
        """Sets the display_missing_episodes of this UserConfiguration.


        :param display_missing_episodes: The display_missing_episodes of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._display_missing_episodes = display_missing_episodes

    @property
    def subtitle_mode(self):
        """Gets the subtitle_mode of this UserConfiguration.  # noqa: E501


        :return: The subtitle_mode of this UserConfiguration.  # noqa: E501
        :rtype: SubtitlePlaybackMode
        """
        return self._subtitle_mode

    @subtitle_mode.setter
    def subtitle_mode(self, subtitle_mode):
        """Sets the subtitle_mode of this UserConfiguration.


        :param subtitle_mode: The subtitle_mode of this UserConfiguration.  # noqa: E501
        :type: SubtitlePlaybackMode
        """

        self._subtitle_mode = subtitle_mode

    @property
    def ordered_views(self):
        """Gets the ordered_views of this UserConfiguration.  # noqa: E501


        :return: The ordered_views of this UserConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._ordered_views

    @ordered_views.setter
    def ordered_views(self, ordered_views):
        """Sets the ordered_views of this UserConfiguration.


        :param ordered_views: The ordered_views of this UserConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._ordered_views = ordered_views

    @property
    def latest_items_excludes(self):
        """Gets the latest_items_excludes of this UserConfiguration.  # noqa: E501


        :return: The latest_items_excludes of this UserConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._latest_items_excludes

    @latest_items_excludes.setter
    def latest_items_excludes(self, latest_items_excludes):
        """Sets the latest_items_excludes of this UserConfiguration.


        :param latest_items_excludes: The latest_items_excludes of this UserConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._latest_items_excludes = latest_items_excludes

    @property
    def my_media_excludes(self):
        """Gets the my_media_excludes of this UserConfiguration.  # noqa: E501


        :return: The my_media_excludes of this UserConfiguration.  # noqa: E501
        :rtype: list[str]
        """
        return self._my_media_excludes

    @my_media_excludes.setter
    def my_media_excludes(self, my_media_excludes):
        """Sets the my_media_excludes of this UserConfiguration.


        :param my_media_excludes: The my_media_excludes of this UserConfiguration.  # noqa: E501
        :type: list[str]
        """

        self._my_media_excludes = my_media_excludes

    @property
    def hide_played_in_latest(self):
        """Gets the hide_played_in_latest of this UserConfiguration.  # noqa: E501


        :return: The hide_played_in_latest of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._hide_played_in_latest

    @hide_played_in_latest.setter
    def hide_played_in_latest(self, hide_played_in_latest):
        """Sets the hide_played_in_latest of this UserConfiguration.


        :param hide_played_in_latest: The hide_played_in_latest of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._hide_played_in_latest = hide_played_in_latest

    @property
    def hide_played_in_more_like_this(self):
        """Gets the hide_played_in_more_like_this of this UserConfiguration.  # noqa: E501


        :return: The hide_played_in_more_like_this of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._hide_played_in_more_like_this

    @hide_played_in_more_like_this.setter
    def hide_played_in_more_like_this(self, hide_played_in_more_like_this):
        """Sets the hide_played_in_more_like_this of this UserConfiguration.


        :param hide_played_in_more_like_this: The hide_played_in_more_like_this of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._hide_played_in_more_like_this = hide_played_in_more_like_this

    @property
    def hide_played_in_suggestions(self):
        """Gets the hide_played_in_suggestions of this UserConfiguration.  # noqa: E501


        :return: The hide_played_in_suggestions of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._hide_played_in_suggestions

    @hide_played_in_suggestions.setter
    def hide_played_in_suggestions(self, hide_played_in_suggestions):
        """Sets the hide_played_in_suggestions of this UserConfiguration.


        :param hide_played_in_suggestions: The hide_played_in_suggestions of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._hide_played_in_suggestions = hide_played_in_suggestions

    @property
    def remember_audio_selections(self):
        """Gets the remember_audio_selections of this UserConfiguration.  # noqa: E501


        :return: The remember_audio_selections of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._remember_audio_selections

    @remember_audio_selections.setter
    def remember_audio_selections(self, remember_audio_selections):
        """Sets the remember_audio_selections of this UserConfiguration.


        :param remember_audio_selections: The remember_audio_selections of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._remember_audio_selections = remember_audio_selections

    @property
    def remember_subtitle_selections(self):
        """Gets the remember_subtitle_selections of this UserConfiguration.  # noqa: E501


        :return: The remember_subtitle_selections of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._remember_subtitle_selections

    @remember_subtitle_selections.setter
    def remember_subtitle_selections(self, remember_subtitle_selections):
        """Sets the remember_subtitle_selections of this UserConfiguration.


        :param remember_subtitle_selections: The remember_subtitle_selections of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._remember_subtitle_selections = remember_subtitle_selections

    @property
    def enable_next_episode_auto_play(self):
        """Gets the enable_next_episode_auto_play of this UserConfiguration.  # noqa: E501


        :return: The enable_next_episode_auto_play of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_next_episode_auto_play

    @enable_next_episode_auto_play.setter
    def enable_next_episode_auto_play(self, enable_next_episode_auto_play):
        """Sets the enable_next_episode_auto_play of this UserConfiguration.


        :param enable_next_episode_auto_play: The enable_next_episode_auto_play of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_next_episode_auto_play = enable_next_episode_auto_play

    @property
    def resume_rewind_seconds(self):
        """Gets the resume_rewind_seconds of this UserConfiguration.  # noqa: E501


        :return: The resume_rewind_seconds of this UserConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._resume_rewind_seconds

    @resume_rewind_seconds.setter
    def resume_rewind_seconds(self, resume_rewind_seconds):
        """Sets the resume_rewind_seconds of this UserConfiguration.


        :param resume_rewind_seconds: The resume_rewind_seconds of this UserConfiguration.  # noqa: E501
        :type: int
        """

        self._resume_rewind_seconds = resume_rewind_seconds

    @property
    def intro_skip_mode(self):
        """Gets the intro_skip_mode of this UserConfiguration.  # noqa: E501


        :return: The intro_skip_mode of this UserConfiguration.  # noqa: E501
        :rtype: SegmentSkipMode
        """
        return self._intro_skip_mode

    @intro_skip_mode.setter
    def intro_skip_mode(self, intro_skip_mode):
        """Sets the intro_skip_mode of this UserConfiguration.


        :param intro_skip_mode: The intro_skip_mode of this UserConfiguration.  # noqa: E501
        :type: SegmentSkipMode
        """

        self._intro_skip_mode = intro_skip_mode

    @property
    def enable_local_password(self):
        """Gets the enable_local_password of this UserConfiguration.  # noqa: E501


        :return: The enable_local_password of this UserConfiguration.  # noqa: E501
        :rtype: bool
        """
        return self._enable_local_password

    @enable_local_password.setter
    def enable_local_password(self, enable_local_password):
        """Sets the enable_local_password of this UserConfiguration.


        :param enable_local_password: The enable_local_password of this UserConfiguration.  # noqa: E501
        :type: bool
        """

        self._enable_local_password = enable_local_password

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class SyncJobItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'job_id': 'int',
        'item_id': 'int',
        'item_name': 'str',
        'media_source_id': 'str',
        'media_source': 'MediaSourceInfo',
        'target_id': 'str',
        'internal_target_id': 'int',
        'output_path': 'str',
        'status': 'SyncJobItemStatus',
        'progress': 'float',
        'date_created': 'datetime',
        'primary_image_item_id': 'str',
        'primary_image_tag': 'str',
        'temporary_path': 'str',
        'additional_files': 'list[ItemFileInfo]'
    }

    attribute_map = {
        'id': 'Id',
        'job_id': 'JobId',
        'item_id': 'ItemId',
        'item_name': 'ItemName',
        'media_source_id': 'MediaSourceId',
        'media_source': 'MediaSource',
        'target_id': 'TargetId',
        'internal_target_id': 'InternalTargetId',
        'output_path': 'OutputPath',
        'status': 'Status',
        'progress': 'Progress',
        'date_created': 'DateCreated',
        'primary_image_item_id': 'PrimaryImageItemId',
        'primary_image_tag': 'PrimaryImageTag',
        'temporary_path': 'TemporaryPath',
        'additional_files': 'AdditionalFiles'
    }

    def __init__(self, id=None, job_id=None, item_id=None, item_name=None, media_source_id=None, media_source=None, target_id=None, internal_target_id=None, output_path=None, status=None, progress=None, date_created=None, primary_image_item_id=None, primary_image_tag=None, temporary_path=None, additional_files=None):  # noqa: E501
        """SyncJobItem - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._job_id = None
        self._item_id = None
        self._item_name = None
        self._media_source_id = None
        self._media_source = None
        self._target_id = None
        self._internal_target_id = None
        self._output_path = None
        self._status = None
        self._progress = None
        self._date_created = None
        self._primary_image_item_id = None
        self._primary_image_tag = None
        self._temporary_path = None
        self._additional_files = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if job_id is not None:
            self.job_id = job_id
        if item_id is not None:
            self.item_id = item_id
        if item_name is not None:
            self.item_name = item_name
        if media_source_id is not None:
            self.media_source_id = media_source_id
        if media_source is not None:
            self.media_source = media_source
        if target_id is not None:
            self.target_id = target_id
        if internal_target_id is not None:
            self.internal_target_id = internal_target_id
        if output_path is not None:
            self.output_path = output_path
        if status is not None:
            self.status = status
        if progress is not None:
            self.progress = progress
        if date_created is not None:
            self.date_created = date_created
        if primary_image_item_id is not None:
            self.primary_image_item_id = primary_image_item_id
        if primary_image_tag is not None:
            self.primary_image_tag = primary_image_tag
        if temporary_path is not None:
            self.temporary_path = temporary_path
        if additional_files is not None:
            self.additional_files = additional_files

    @property
    def id(self):
        """Gets the id of this SyncJobItem.  # noqa: E501


        :return: The id of this SyncJobItem.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SyncJobItem.


        :param id: The id of this SyncJobItem.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def job_id(self):
        """Gets the job_id of this SyncJobItem.  # noqa: E501


        :return: The job_id of this SyncJobItem.  # noqa: E501
        :rtype: int
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this SyncJobItem.


        :param job_id: The job_id of this SyncJobItem.  # noqa: E501
        :type: int
        """

        self._job_id = job_id

    @property
    def item_id(self):
        """Gets the item_id of this SyncJobItem.  # noqa: E501


        :return: The item_id of this SyncJobItem.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this SyncJobItem.


        :param item_id: The item_id of this SyncJobItem.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def item_name(self):
        """Gets the item_name of this SyncJobItem.  # noqa: E501


        :return: The item_name of this SyncJobItem.  # noqa: E501
        :rtype: str
        """
        return self._item_name

    @item_name.setter
    def item_name(self, item_name):
        """Sets the item_name of this SyncJobItem.


        :param item_name: The item_name of this SyncJobItem.  # noqa: E501
        :type: str
        """

        self._item_name = item_name

    @property
    def media_source_id(self):
        """Gets the media_source_id of this SyncJobItem.  # noqa: E501


        :return: The media_source_id of this SyncJobItem.  # noqa: E501
        :rtype: str
        """
        return self._media_source_id

    @media_source_id.setter
    def media_source_id(self, media_source_id):
        """Sets the media_source_id of this SyncJobItem.


        :param media_source_id: The media_source_id of this SyncJobItem.  # noqa: E501
        :type: str
        """

        self._media_source_id = media_source_id

    @property
    def media_source(self):
        """Gets the media_source of this SyncJobItem.  # noqa: E501


        :return: The media_source of this SyncJobItem.  # noqa: E501
        :rtype: MediaSourceInfo
        """
        return self._media_source

    @media_source.setter
    def media_source(self, media_source):
        """Sets the media_source of this SyncJobItem.


        :param media_source: The media_source of this SyncJobItem.  # noqa: E501
        :type: MediaSourceInfo
        """

        self._media_source = media_source

    @property
    def target_id(self):
        """Gets the target_id of this SyncJobItem.  # noqa: E501


        :return: The target_id of this SyncJobItem.  # noqa: E501
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """Sets the target_id of this SyncJobItem.


        :param target_id: The target_id of this SyncJobItem.  # noqa: E501
        :type: str
        """

        self._target_id = target_id

    @property
    def internal_target_id(self):
        """Gets the internal_target_id of this SyncJobItem.  # noqa: E501


        :return: The internal_target_id of this SyncJobItem.  # noqa: E501
        :rtype: int
        """
        return self._internal_target_id

    @internal_target_id.setter
    def internal_target_id(self, internal_target_id):
        """Sets the internal_target_id of this SyncJobItem.


        :param internal_target_id: The internal_target_id of this SyncJobItem.  # noqa: E501
        :type: int
        """

        self._internal_target_id = internal_target_id

    @property
    def output_path(self):
        """Gets the output_path of this SyncJobItem.  # noqa: E501


        :return: The output_path of this SyncJobItem.  # noqa: E501
        :rtype: str
        """
        return self._output_path

    @output_path.setter
    def output_path(self, output_path):
        """Sets the output_path of this SyncJobItem.


        :param output_path: The output_path of this SyncJobItem.  # noqa: E501
        :type: str
        """

        self._output_path = output_path

    @property
    def status(self):
        """Gets the status of this SyncJobItem.  # noqa: E501


        :return: The status of this SyncJobItem.  # noqa: E501
        :rtype: SyncJobItemStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SyncJobItem.


        :param status: The status of this SyncJobItem.  # noqa: E501
        :type: SyncJobItemStatus
        """

        self._status = status

    @property
    def progress(self):
        """Gets the progress of this SyncJobItem.  # noqa: E501


        :return: The progress of this SyncJobItem.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this SyncJobItem.


        :param progress: The progress of this SyncJobItem.  # noqa: E501
        :type: float
        """

        self._progress = progress

    @property
    def date_created(self):
        """Gets the date_created of this SyncJobItem.  # noqa: E501


        :return: The date_created of this SyncJobItem.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this SyncJobItem.


        :param date_created: The date_created of this SyncJobItem.  # noqa: E501
        :type: datetime
        """

        self._date_created = date_created

    @property
    def primary_image_item_id(self):
        """Gets the primary_image_item_id of this SyncJobItem.  # noqa: E501


        :return: The primary_image_item_id of this SyncJobItem.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_item_id

    @primary_image_item_id.setter
    def primary_image_item_id(self, primary_image_item_id):
        """Sets the primary_image_item_id of this SyncJobItem.


        :param primary_image_item_id: The primary_image_item_id of this SyncJobItem.  # noqa: E501
        :type: str
        """

        self._primary_image_item_id = primary_image_item_id

    @property
    def primary_image_tag(self):
        """Gets the primary_image_tag of this SyncJobItem.  # noqa: E501


        :return: The primary_image_tag of this SyncJobItem.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_tag

    @primary_image_tag.setter
    def primary_image_tag(self, primary_image_tag):
        """Sets the primary_image_tag of this SyncJobItem.


        :param primary_image_tag: The primary_image_tag of this SyncJobItem.  # noqa: E501
        :type: str
        """

        self._primary_image_tag = primary_image_tag

    @property
    def temporary_path(self):
        """Gets the temporary_path of this SyncJobItem.  # noqa: E501


        :return: The temporary_path of this SyncJobItem.  # noqa: E501
        :rtype: str
        """
        return self._temporary_path

    @temporary_path.setter
    def temporary_path(self, temporary_path):
        """Sets the temporary_path of this SyncJobItem.


        :param temporary_path: The temporary_path of this SyncJobItem.  # noqa: E501
        :type: str
        """

        self._temporary_path = temporary_path

    @property
    def additional_files(self):
        """Gets the additional_files of this SyncJobItem.  # noqa: E501


        :return: The additional_files of this SyncJobItem.  # noqa: E501
        :rtype: list[ItemFileInfo]
        """
        return self._additional_files

    @additional_files.setter
    def additional_files(self, additional_files):
        """Sets the additional_files of this SyncJobItem.


        :param additional_files: The additional_files of this SyncJobItem.  # noqa: E501
        :type: list[ItemFileInfo]
        """

        self._additional_files = additional_files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SyncJobItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SyncJobItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UserDto(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'server_id': 'str',
        'server_name': 'str',
        'prefix': 'str',
        'connect_user_name': 'str',
        'date_created': 'datetime',
        'connect_link_type': 'ConnectUserLinkType',
        'id': 'str',
        'primary_image_tag': 'str',
        'has_password': 'bool',
        'has_configured_password': 'bool',
        'enable_auto_login': 'bool',
        'last_login_date': 'datetime',
        'last_activity_date': 'datetime',
        'configuration': 'UserConfiguration',
        'policy': 'UserPolicy',
        'primary_image_aspect_ratio': 'float',
        'has_configured_easy_password': 'bool',
        'user_item_share_level': 'UserItemShareLevel'
    }

    attribute_map = {
        'name': 'Name',
        'server_id': 'ServerId',
        'server_name': 'ServerName',
        'prefix': 'Prefix',
        'connect_user_name': 'ConnectUserName',
        'date_created': 'DateCreated',
        'connect_link_type': 'ConnectLinkType',
        'id': 'Id',
        'primary_image_tag': 'PrimaryImageTag',
        'has_password': 'HasPassword',
        'has_configured_password': 'HasConfiguredPassword',
        'enable_auto_login': 'EnableAutoLogin',
        'last_login_date': 'LastLoginDate',
        'last_activity_date': 'LastActivityDate',
        'configuration': 'Configuration',
        'policy': 'Policy',
        'primary_image_aspect_ratio': 'PrimaryImageAspectRatio',
        'has_configured_easy_password': 'HasConfiguredEasyPassword',
        'user_item_share_level': 'UserItemShareLevel'
    }

    def __init__(self, name=None, server_id=None, server_name=None, prefix=None, connect_user_name=None, date_created=None, connect_link_type=None, id=None, primary_image_tag=None, has_password=None, has_configured_password=None, enable_auto_login=None, last_login_date=None, last_activity_date=None, configuration=None, policy=None, primary_image_aspect_ratio=None, has_configured_easy_password=None, user_item_share_level=None):  # noqa: E501
        """UserDto - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._server_id = None
        self._server_name = None
        self._prefix = None
        self._connect_user_name = None
        self._date_created = None
        self._connect_link_type = None
        self._id = None
        self._primary_image_tag = None
        self._has_password = None
        self._has_configured_password = None
        self._enable_auto_login = None
        self._last_login_date = None
        self._last_activity_date = None
        self._configuration = None
        self._policy = None
        self._primary_image_aspect_ratio = None
        self._has_configured_easy_password = None
        self._user_item_share_level = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if server_id is not None:
            self.server_id = server_id
        if server_name is not None:
            self.server_name = server_name
        if prefix is not None:
            self.prefix = prefix
        if connect_user_name is not None:
            self.connect_user_name = connect_user_name
        if date_created is not None:
            self.date_created = date_created
        if connect_link_type is not None:
            self.connect_link_type = connect_link_type
        if id is not None:
            self.id = id
        if primary_image_tag is not None:
            self.primary_image_tag = primary_image_tag
        if has_password is not None:
            self.has_password = has_password
        if has_configured_password is not None:
            self.has_configured_password = has_configured_password
        if enable_auto_login is not None:
            self.enable_auto_login = enable_auto_login
        if last_login_date is not None:
            self.last_login_date = last_login_date
        if last_activity_date is not None:
            self.last_activity_date = last_activity_date
        if configuration is not None:
            self.configuration = configuration
        if policy is not None:
            self.policy = policy
        if primary_image_aspect_ratio is not None:
            self.primary_image_aspect_ratio = primary_image_aspect_ratio
        if has_configured_easy_password is not None:
            self.has_configured_easy_password = has_configured_easy_password
        if user_item_share_level is not None:
            self.user_item_share_level = user_item_share_level

    @property
    def name(self):
        """Gets the name of this UserDto.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this UserDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserDto.

        The name.  # noqa: E501

        :param name: The name of this UserDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def server_id(self):
        """Gets the server_id of this UserDto.  # noqa: E501

        The server identifier.  # noqa: E501

        :return: The server_id of this UserDto.  # noqa: E501
        :rtype: str
        """
        return self._server_id

    @server_id.setter
    def server_id(self, server_id):
        """Sets the server_id of this UserDto.

        The server identifier.  # noqa: E501

        :param server_id: The server_id of this UserDto.  # noqa: E501
        :type: str
        """

        self._server_id = server_id

    @property
    def server_name(self):
        """Gets the server_name of this UserDto.  # noqa: E501

        The name of the server. This is not used by the server and is for client\\-side usage only.  # noqa: E501

        :return: The server_name of this UserDto.  # noqa: E501
        :rtype: str
        """
        return self._server_name

    @server_name.setter
    def server_name(self, server_name):
        """Sets the server_name of this UserDto.

        The name of the server. This is not used by the server and is for client\\-side usage only.  # noqa: E501

        :param server_name: The server_name of this UserDto.  # noqa: E501
        :type: str
        """

        self._server_name = server_name

    @property
    def prefix(self):
        """Gets the prefix of this UserDto.  # noqa: E501


        :return: The prefix of this UserDto.  # noqa: E501
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """Sets the prefix of this UserDto.


        :param prefix: The prefix of this UserDto.  # noqa: E501
        :type: str
        """

        self._prefix = prefix

    @property
    def connect_user_name(self):
        """Gets the connect_user_name of this UserDto.  # noqa: E501

        The name of the connect user.  # noqa: E501

        :return: The connect_user_name of this UserDto.  # noqa: E501
        :rtype: str
        """
        return self._connect_user_name

    @connect_user_name.setter
    def connect_user_name(self, connect_user_name):
        """Sets the connect_user_name of this UserDto.

        The name of the connect user.  # noqa: E501

        :param connect_user_name: The connect_user_name of this UserDto.  # noqa: E501
        :type: str
        """

        self._connect_user_name = connect_user_name

    @property
    def date_created(self):
        """Gets the date_created of this UserDto.  # noqa: E501


        :return: The date_created of this UserDto.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this UserDto.


        :param date_created: The date_created of this UserDto.  # noqa: E501
        :type: datetime
        """

        self._date_created = date_created

    @property
    def connect_link_type(self):
        """Gets the connect_link_type of this UserDto.  # noqa: E501


        :return: The connect_link_type of this UserDto.  # noqa: E501
        :rtype: ConnectUserLinkType
        """
        return self._connect_link_type

    @connect_link_type.setter
    def connect_link_type(self, connect_link_type):
        """Sets the connect_link_type of this UserDto.


        :param connect_link_type: The connect_link_type of this UserDto.  # noqa: E501
        :type: ConnectUserLinkType
        """

        self._connect_link_type = connect_link_type

    @property
    def id(self):
        """Gets the id of this UserDto.  # noqa: E501

        The id.  # noqa: E501

        :return: The id of this UserDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserDto.

        The id.  # noqa: E501

        :param id: The id of this UserDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def primary_image_tag(self):
        """Gets the primary_image_tag of this UserDto.  # noqa: E501

        The primary image tag.  # noqa: E501

        :return: The primary_image_tag of this UserDto.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_tag

    @primary_image_tag.setter
    def primary_image_tag(self, primary_image_tag):
        """Sets the primary_image_tag of this UserDto.

        The primary image tag.  # noqa: E501

        :param primary_image_tag: The primary_image_tag of this UserDto.  # noqa: E501
        :type: str
        """

        self._primary_image_tag = primary_image_tag

    @property
    def has_password(self):
        """Gets the has_password of this UserDto.  # noqa: E501

        A value indicating whether this instance has password.  # noqa: E501

        :return: The has_password of this UserDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_password

    @has_password.setter
    def has_password(self, has_password):
        """Sets the has_password of this UserDto.

        A value indicating whether this instance has password.  # noqa: E501

        :param has_password: The has_password of this UserDto.  # noqa: E501
        :type: bool
        """

        self._has_password = has_password

    @property
    def has_configured_password(self):
        """Gets the has_configured_password of this UserDto.  # noqa: E501

        A value indicating whether this instance has configured password.  # noqa: E501

        :return: The has_configured_password of this UserDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_configured_password

    @has_configured_password.setter
    def has_configured_password(self, has_configured_password):
        """Sets the has_configured_password of this UserDto.

        A value indicating whether this instance has configured password.  # noqa: E501

        :param has_configured_password: The has_configured_password of this UserDto.  # noqa: E501
        :type: bool
        """

        self._has_configured_password = has_configured_password

    @property
    def enable_auto_login(self):
        """Gets the enable_auto_login of this UserDto.  # noqa: E501


        :return: The enable_auto_login of this UserDto.  # noqa: E501
        :rtype: bool
        """
        return self._enable_auto_login

    @enable_auto_login.setter
    def enable_auto_login(self, enable_auto_login):
        """Sets the enable_auto_login of this UserDto.


        :param enable_auto_login: The enable_auto_login of this UserDto.  # noqa: E501
        :type: bool
        """

        self._enable_auto_login = enable_auto_login

    @property
    def last_login_date(self):
        """Gets the last_login_date of this UserDto.  # noqa: E501

        The last login date.  # noqa: E501

        :return: The last_login_date of this UserDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_login_date

    @last_login_date.setter
    def last_login_date(self, last_login_date):
        """Sets the last_login_date of this UserDto.

        The last login date.  # noqa: E501

        :param last_login_date: The last_login_date of this UserDto.  # noqa: E501
        :type: datetime
        """

        self._last_login_date = last_login_date

    @property
    def last_activity_date(self):
        """Gets the last_activity_date of this UserDto.  # noqa: E501

        The last activity date.  # noqa: E501

        :return: The last_activity_date of this UserDto.  # noqa: E501
        :rtype: datetime
        """
        return self._last_activity_date

    @last_activity_date.setter
    def last_activity_date(self, last_activity_date):
        """Sets the last_activity_date of this UserDto.

        The last activity date.  # noqa: E501

        :param last_activity_date: The last_activity_date of this UserDto.  # noqa: E501
        :type: datetime
        """

        self._last_activity_date = last_activity_date

    @property
    def configuration(self):
        """Gets the configuration of this UserDto.  # noqa: E501


        :return: The configuration of this UserDto.  # noqa: E501
        :rtype: UserConfiguration
        """
        return self._configuration

    @configuration.setter
    def configuration(self, configuration):
        """Sets the configuration of this UserDto.


        :param configuration: The configuration of this UserDto.  # noqa: E501
        :type: UserConfiguration
        """

        self._configuration = configuration

    @property
    def policy(self):
        """Gets the policy of this UserDto.  # noqa: E501


        :return: The policy of this UserDto.  # noqa: E501
        :rtype: UserPolicy
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this UserDto.


        :param policy: The policy of this UserDto.  # noqa: E501
        :type: UserPolicy
        """

        self._policy = policy

    @property
    def primary_image_aspect_ratio(self):
        """Gets the primary_image_aspect_ratio of this UserDto.  # noqa: E501

        The primary image aspect ratio.  # noqa: E501

        :return: The primary_image_aspect_ratio of this UserDto.  # noqa: E501
        :rtype: float
        """
        return self._primary_image_aspect_ratio

    @primary_image_aspect_ratio.setter
    def primary_image_aspect_ratio(self, primary_image_aspect_ratio):
        """Sets the primary_image_aspect_ratio of this UserDto.

        The primary image aspect ratio.  # noqa: E501

        :param primary_image_aspect_ratio: The primary_image_aspect_ratio of this UserDto.  # noqa: E501
        :type: float
        """

        self._primary_image_aspect_ratio = primary_image_aspect_ratio

    @property
    def has_configured_easy_password(self):
        """Gets the has_configured_easy_password of this UserDto.  # noqa: E501


        :return: The has_configured_easy_password of this UserDto.  # noqa: E501
        :rtype: bool
        """
        return self._has_configured_easy_password

    @has_configured_easy_password.setter
    def has_configured_easy_password(self, has_configured_easy_password):
        """Sets the has_configured_easy_password of this UserDto.


        :param has_configured_easy_password: The has_configured_easy_password of this UserDto.  # noqa: E501
        :type: bool
        """

        self._has_configured_easy_password = has_configured_easy_password

    @property
    def user_item_share_level(self):
        """Gets the user_item_share_level of this UserDto.  # noqa: E501


        :return: The user_item_share_level of this UserDto.  # noqa: E501
        :rtype: UserItemShareLevel
        """
        return self._user_item_share_level

    @user_item_share_level.setter
    def user_item_share_level(self, user_item_share_level):
        """Sets the user_item_share_level of this UserDto.


        :param user_item_share_level: The user_item_share_level of this UserDto.  # noqa: E501
        :type: UserItemShareLevel
        """

        self._user_item_share_level = user_item_share_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserDto, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LiveTvTunerHostInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'url': 'str',
        'type': 'str',
        'device_id': 'str',
        'friendly_name': 'str',
        'setup_url': 'str',
        'import_favorites_only': 'bool',
        'prefer_epg_channel_images': 'bool',
        'prefer_epg_channel_numbers': 'bool',
        'allow_hw_transcoding': 'bool',
        'allow_mapping_by_number': 'bool',
        'import_guide_data': 'bool',
        'source': 'str',
        'tuner_count': 'int',
        'user_agent': 'str',
        'referrer': 'str',
        'provider_options': 'str',
        'data_version': 'int'
    }

    attribute_map = {
        'id': 'Id',
        'url': 'Url',
        'type': 'Type',
        'device_id': 'DeviceId',
        'friendly_name': 'FriendlyName',
        'setup_url': 'SetupUrl',
        'import_favorites_only': 'ImportFavoritesOnly',
        'prefer_epg_channel_images': 'PreferEpgChannelImages',
        'prefer_epg_channel_numbers': 'PreferEpgChannelNumbers',
        'allow_hw_transcoding': 'AllowHWTranscoding',
        'allow_mapping_by_number': 'AllowMappingByNumber',
        'import_guide_data': 'ImportGuideData',
        'source': 'Source',
        'tuner_count': 'TunerCount',
        'user_agent': 'UserAgent',
        'referrer': 'Referrer',
        'provider_options': 'ProviderOptions',
        'data_version': 'DataVersion'
    }

    def __init__(self, id=None, url=None, type=None, device_id=None, friendly_name=None, setup_url=None, import_favorites_only=None, prefer_epg_channel_images=None, prefer_epg_channel_numbers=None, allow_hw_transcoding=None, allow_mapping_by_number=None, import_guide_data=None, source=None, tuner_count=None, user_agent=None, referrer=None, provider_options=None, data_version=None):  # noqa: E501
        """LiveTvTunerHostInfo - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._url = None
        self._type = None
        self._device_id = None
        self._friendly_name = None
        self._setup_url = None
        self._import_favorites_only = None
        self._prefer_epg_channel_images = None
        self._prefer_epg_channel_numbers = None
        self._allow_hw_transcoding = None
        self._allow_mapping_by_number = None
        self._import_guide_data = None
        self._source = None
        self._tuner_count = None
        self._user_agent = None
        self._referrer = None
        self._provider_options = None
        self._data_version = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if url is not None:
            self.url = url
        if type is not None:
            self.type = type
        if device_id is not None:
            self.device_id = device_id
        if friendly_name is not None:
            self.friendly_name = friendly_name
        if setup_url is not None:
            self.setup_url = setup_url
        if import_favorites_only is not None:
            self.import_favorites_only = import_favorites_only
        if prefer_epg_channel_images is not None:
            self.prefer_epg_channel_images = prefer_epg_channel_images
        if prefer_epg_channel_numbers is not None:
            self.prefer_epg_channel_numbers = prefer_epg_channel_numbers
        if allow_hw_transcoding is not None:
            self.allow_hw_transcoding = allow_hw_transcoding
        if allow_mapping_by_number is not None:
            self.allow_mapping_by_number = allow_mapping_by_number
        if import_guide_data is not None:
            self.import_guide_data = import_guide_data
        if source is not None:
            self.source = source
        if tuner_count is not None:
            self.tuner_count = tuner_count
        if user_agent is not None:
            self.user_agent = user_agent
        if referrer is not None:
            self.referrer = referrer
        if provider_options is not None:
            self.provider_options = provider_options
        if data_version is not None:
            self.data_version = data_version

    @property
    def id(self):
        """Gets the id of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The id of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LiveTvTunerHostInfo.


        :param id: The id of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def url(self):
        """Gets the url of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The url of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this LiveTvTunerHostInfo.


        :param url: The url of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def type(self):
        """Gets the type of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The type of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this LiveTvTunerHostInfo.


        :param type: The type of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def device_id(self):
        """Gets the device_id of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The device_id of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this LiveTvTunerHostInfo.


        :param device_id: The device_id of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def friendly_name(self):
        """Gets the friendly_name of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The friendly_name of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._friendly_name

    @friendly_name.setter
    def friendly_name(self, friendly_name):
        """Sets the friendly_name of this LiveTvTunerHostInfo.


        :param friendly_name: The friendly_name of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._friendly_name = friendly_name

    @property
    def setup_url(self):
        """Gets the setup_url of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The setup_url of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._setup_url

    @setup_url.setter
    def setup_url(self, setup_url):
        """Sets the setup_url of this LiveTvTunerHostInfo.


        :param setup_url: The setup_url of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._setup_url = setup_url

    @property
    def import_favorites_only(self):
        """Gets the import_favorites_only of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The import_favorites_only of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: bool
        """
        return self._import_favorites_only

    @import_favorites_only.setter
    def import_favorites_only(self, import_favorites_only):
        """Sets the import_favorites_only of this LiveTvTunerHostInfo.


        :param import_favorites_only: The import_favorites_only of this LiveTvTunerHostInfo.  # noqa: E501
        :type: bool
        """

        self._import_favorites_only = import_favorites_only

    @property
    def prefer_epg_channel_images(self):
        """Gets the prefer_epg_channel_images of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The prefer_epg_channel_images of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: bool
        """
        return self._prefer_epg_channel_images

    @prefer_epg_channel_images.setter
    def prefer_epg_channel_images(self, prefer_epg_channel_images):
        """Sets the prefer_epg_channel_images of this LiveTvTunerHostInfo.


        :param prefer_epg_channel_images: The prefer_epg_channel_images of this LiveTvTunerHostInfo.  # noqa: E501
        :type: bool
        """

        self._prefer_epg_channel_images = prefer_epg_channel_images

    @property
    def prefer_epg_channel_numbers(self):
        """Gets the prefer_epg_channel_numbers of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The prefer_epg_channel_numbers of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: bool
        """
        return self._prefer_epg_channel_numbers

    @prefer_epg_channel_numbers.setter
    def prefer_epg_channel_numbers(self, prefer_epg_channel_numbers):
        """Sets the prefer_epg_channel_numbers of this LiveTvTunerHostInfo.


        :param prefer_epg_channel_numbers: The prefer_epg_channel_numbers of this LiveTvTunerHostInfo.  # noqa: E501
        :type: bool
        """

        self._prefer_epg_channel_numbers = prefer_epg_channel_numbers

    @property
    def allow_hw_transcoding(self):
        """Gets the allow_hw_transcoding of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The allow_hw_transcoding of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: bool
        """
        return self._allow_hw_transcoding

    @allow_hw_transcoding.setter
    def allow_hw_transcoding(self, allow_hw_transcoding):
        """Sets the allow_hw_transcoding of this LiveTvTunerHostInfo.


        :param allow_hw_transcoding: The allow_hw_transcoding of this LiveTvTunerHostInfo.  # noqa: E501
        :type: bool
        """

        self._allow_hw_transcoding = allow_hw_transcoding

    @property
    def allow_mapping_by_number(self):
        """Gets the allow_mapping_by_number of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The allow_mapping_by_number of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: bool
        """
        return self._allow_mapping_by_number

    @allow_mapping_by_number.setter
    def allow_mapping_by_number(self, allow_mapping_by_number):
        """Sets the allow_mapping_by_number of this LiveTvTunerHostInfo.


        :param allow_mapping_by_number: The allow_mapping_by_number of this LiveTvTunerHostInfo.  # noqa: E501
        :type: bool
        """

        self._allow_mapping_by_number = allow_mapping_by_number

    @property
    def import_guide_data(self):
        """Gets the import_guide_data of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The import_guide_data of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: bool
        """
        return self._import_guide_data

    @import_guide_data.setter
    def import_guide_data(self, import_guide_data):
        """Sets the import_guide_data of this LiveTvTunerHostInfo.


        :param import_guide_data: The import_guide_data of this LiveTvTunerHostInfo.  # noqa: E501
        :type: bool
        """

        self._import_guide_data = import_guide_data

    @property
    def source(self):
        """Gets the source of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The source of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this LiveTvTunerHostInfo.


        :param source: The source of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def tuner_count(self):
        """Gets the tuner_count of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The tuner_count of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: int
        """
        return self._tuner_count

    @tuner_count.setter
    def tuner_count(self, tuner_count):
        """Sets the tuner_count of this LiveTvTunerHostInfo.


        :param tuner_count: The tuner_count of this LiveTvTunerHostInfo.  # noqa: E501
        :type: int
        """

        self._tuner_count = tuner_count

    @property
    def user_agent(self):
        """Gets the user_agent of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The user_agent of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """Sets the user_agent of this LiveTvTunerHostInfo.


        :param user_agent: The user_agent of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._user_agent = user_agent

    @property
    def referrer(self):
        """Gets the referrer of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The referrer of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._referrer

    @referrer.setter
    def referrer(self, referrer):
        """Sets the referrer of this LiveTvTunerHostInfo.


        :param referrer: The referrer of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._referrer = referrer

    @property
    def provider_options(self):
        """Gets the provider_options of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The provider_options of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: str
        """
        return self._provider_options

    @provider_options.setter
    def provider_options(self, provider_options):
        """Sets the provider_options of this LiveTvTunerHostInfo.


        :param provider_options: The provider_options of this LiveTvTunerHostInfo.  # noqa: E501
        :type: str
        """

        self._provider_options = provider_options

    @property
    def data_version(self):
        """Gets the data_version of this LiveTvTunerHostInfo.  # noqa: E501


        :return: The data_version of this LiveTvTunerHostInfo.  # noqa: E501
        :rtype: int
        """
        return self._data_version

    @data_version.setter
    def data_version(self, data_version):
        """Sets the data_version of this LiveTvTunerHostInfo.


        :param data_version: The data_version of this LiveTvTunerHostInfo.  # noqa: E501
        :type: int
        """

        self._data_version = data_version

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LiveTvTunerHostInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LiveTvTunerHostInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class VirtualFolderInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'locations': 'list[str]',
        'collection_type': 'str',
        'library_options': 'LibraryOptions',
        'item_id': 'str',
        'id': 'str',
        'guid': 'str',
        'primary_image_item_id': 'str',
        'primary_image_tag': 'str',
        'refresh_progress': 'float',
        'refresh_status': 'str'
    }

    attribute_map = {
        'name': 'Name',
        'locations': 'Locations',
        'collection_type': 'CollectionType',
        'library_options': 'LibraryOptions',
        'item_id': 'ItemId',
        'id': 'Id',
        'guid': 'Guid',
        'primary_image_item_id': 'PrimaryImageItemId',
        'primary_image_tag': 'PrimaryImageTag',
        'refresh_progress': 'RefreshProgress',
        'refresh_status': 'RefreshStatus'
    }

    def __init__(self, name=None, locations=None, collection_type=None, library_options=None, item_id=None, id=None, guid=None, primary_image_item_id=None, primary_image_tag=None, refresh_progress=None, refresh_status=None):  # noqa: E501
        """VirtualFolderInfo - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._locations = None
        self._collection_type = None
        self._library_options = None
        self._item_id = None
        self._id = None
        self._guid = None
        self._primary_image_item_id = None
        self._primary_image_tag = None
        self._refresh_progress = None
        self._refresh_status = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if locations is not None:
            self.locations = locations
        if collection_type is not None:
            self.collection_type = collection_type
        if library_options is not None:
            self.library_options = library_options
        if item_id is not None:
            self.item_id = item_id
        if id is not None:
            self.id = id
        if guid is not None:
            self.guid = guid
        if primary_image_item_id is not None:
            self.primary_image_item_id = primary_image_item_id
        if primary_image_tag is not None:
            self.primary_image_tag = primary_image_tag
        if refresh_progress is not None:
            self.refresh_progress = refresh_progress
        if refresh_status is not None:
            self.refresh_status = refresh_status

    @property
    def name(self):
        """Gets the name of this VirtualFolderInfo.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VirtualFolderInfo.

        The name.  # noqa: E501

        :param name: The name of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def locations(self):
        """Gets the locations of this VirtualFolderInfo.  # noqa: E501

        The locations.  # noqa: E501

        :return: The locations of this VirtualFolderInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this VirtualFolderInfo.

        The locations.  # noqa: E501

        :param locations: The locations of this VirtualFolderInfo.  # noqa: E501
        :type: list[str]
        """

        self._locations = locations

    @property
    def collection_type(self):
        """Gets the collection_type of this VirtualFolderInfo.  # noqa: E501

        The type of the collection.  # noqa: E501

        :return: The collection_type of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._collection_type

    @collection_type.setter
    def collection_type(self, collection_type):
        """Sets the collection_type of this VirtualFolderInfo.

        The type of the collection.  # noqa: E501

        :param collection_type: The collection_type of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._collection_type = collection_type

    @property
    def library_options(self):
        """Gets the library_options of this VirtualFolderInfo.  # noqa: E501


        :return: The library_options of this VirtualFolderInfo.  # noqa: E501
        :rtype: LibraryOptions
        """
        return self._library_options

    @library_options.setter
    def library_options(self, library_options):
        """Sets the library_options of this VirtualFolderInfo.


        :param library_options: The library_options of this VirtualFolderInfo.  # noqa: E501
        :type: LibraryOptions
        """

        self._library_options = library_options

    @property
    def item_id(self):
        """Gets the item_id of this VirtualFolderInfo.  # noqa: E501

        The item identifier.  # noqa: E501

        :return: The item_id of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this VirtualFolderInfo.

        The item identifier.  # noqa: E501

        :param item_id: The item_id of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def id(self):
        """Gets the id of this VirtualFolderInfo.  # noqa: E501

        ItemId came first, so that is left for compatability purposes  # noqa: E501

        :return: The id of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this VirtualFolderInfo.

        ItemId came first, so that is left for compatability purposes  # noqa: E501

        :param id: The id of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def guid(self):
        """Gets the guid of this VirtualFolderInfo.  # noqa: E501


        :return: The guid of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._guid

    @guid.setter
    def guid(self, guid):
        """Sets the guid of this VirtualFolderInfo.


        :param guid: The guid of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._guid = guid

    @property
    def primary_image_item_id(self):
        """Gets the primary_image_item_id of this VirtualFolderInfo.  # noqa: E501

        The primary image item identifier.  # noqa: E501

        :return: The primary_image_item_id of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_item_id

    @primary_image_item_id.setter
    def primary_image_item_id(self, primary_image_item_id):
        """Sets the primary_image_item_id of this VirtualFolderInfo.

        The primary image item identifier.  # noqa: E501

        :param primary_image_item_id: The primary_image_item_id of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._primary_image_item_id = primary_image_item_id

    @property
    def primary_image_tag(self):
        """Gets the primary_image_tag of this VirtualFolderInfo.  # noqa: E501


        :return: The primary_image_tag of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._primary_image_tag

    @primary_image_tag.setter
    def primary_image_tag(self, primary_image_tag):
        """Sets the primary_image_tag of this VirtualFolderInfo.


        :param primary_image_tag: The primary_image_tag of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._primary_image_tag = primary_image_tag

    @property
    def refresh_progress(self):
        """Gets the refresh_progress of this VirtualFolderInfo.  # noqa: E501


        :return: The refresh_progress of this VirtualFolderInfo.  # noqa: E501
        :rtype: float
        """
        return self._refresh_progress

    @refresh_progress.setter
    def refresh_progress(self, refresh_progress):
        """Sets the refresh_progress of this VirtualFolderInfo.


        :param refresh_progress: The refresh_progress of this VirtualFolderInfo.  # noqa: E501
        :type: float
        """

        self._refresh_progress = refresh_progress

    @property
    def refresh_status(self):
        """Gets the refresh_status of this VirtualFolderInfo.  # noqa: E501


        :return: The refresh_status of this VirtualFolderInfo.  # noqa: E501
        :rtype: str
        """
        return self._refresh_status

    @refresh_status.setter
    def refresh_status(self, refresh_status):
        """Sets the refresh_status of this VirtualFolderInfo.


        :param refresh_status: The refresh_status of this VirtualFolderInfo.  # noqa: E501
        :type: str
        """

        self._refresh_status = refresh_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(VirtualFolderInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VirtualFolderInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class PlaybackProgressInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'can_seek': 'bool',
        'item': 'BaseItemDto',
        'now_playing_queue': 'list[QueueItem]',
        'playlist_item_id': 'str',
        'item_id': 'str',
        'session_id': 'str',
        'media_source_id': 'str',
        'audio_stream_index': 'int',
        'subtitle_stream_index': 'int',
        'is_paused': 'bool',
        'playlist_index': 'int',
        'playlist_length': 'int',
        'is_muted': 'bool',
        'position_ticks': 'int',
        'run_time_ticks': 'int',
        'playback_start_time_ticks': 'int',
        'volume_level': 'int',
        'brightness': 'int',
        'aspect_ratio': 'str',
        'event_name': 'ProgressEvent',
        'play_method': 'PlayMethod',
        'live_stream_id': 'str',
        'play_session_id': 'str',
        'repeat_mode': 'RepeatMode',
        'shuffle': 'bool',
        'subtitle_offset': 'int',
        'playback_rate': 'float',
        'playlist_item_ids': 'list[str]'
    }

    attribute_map = {
        'can_seek': 'CanSeek',
        'item': 'Item',
        'now_playing_queue': 'NowPlayingQueue',
        'playlist_item_id': 'PlaylistItemId',
        'item_id': 'ItemId',
        'session_id': 'SessionId',
        'media_source_id': 'MediaSourceId',
        'audio_stream_index': 'AudioStreamIndex',
        'subtitle_stream_index': 'SubtitleStreamIndex',
        'is_paused': 'IsPaused',
        'playlist_index': 'PlaylistIndex',
        'playlist_length': 'PlaylistLength',
        'is_muted': 'IsMuted',
        'position_ticks': 'PositionTicks',
        'run_time_ticks': 'RunTimeTicks',
        'playback_start_time_ticks': 'PlaybackStartTimeTicks',
        'volume_level': 'VolumeLevel',
        'brightness': 'Brightness',
        'aspect_ratio': 'AspectRatio',
        'event_name': 'EventName',
        'play_method': 'PlayMethod',
        'live_stream_id': 'LiveStreamId',
        'play_session_id': 'PlaySessionId',
        'repeat_mode': 'RepeatMode',
        'shuffle': 'Shuffle',
        'subtitle_offset': 'SubtitleOffset',
        'playback_rate': 'PlaybackRate',
        'playlist_item_ids': 'PlaylistItemIds'
    }

    def __init__(self, can_seek=None, item=None, now_playing_queue=None, playlist_item_id=None, item_id=None, session_id=None, media_source_id=None, audio_stream_index=None, subtitle_stream_index=None, is_paused=None, playlist_index=None, playlist_length=None, is_muted=None, position_ticks=None, run_time_ticks=None, playback_start_time_ticks=None, volume_level=None, brightness=None, aspect_ratio=None, event_name=None, play_method=None, live_stream_id=None, play_session_id=None, repeat_mode=None, shuffle=None, subtitle_offset=None, playback_rate=None, playlist_item_ids=None):  # noqa: E501
        """PlaybackProgressInfo - a model defined in Swagger"""  # noqa: E501
        self._can_seek = None
        self._item = None
        self._now_playing_queue = None
        self._playlist_item_id = None
        self._item_id = None
        self._session_id = None
        self._media_source_id = None
        self._audio_stream_index = None
        self._subtitle_stream_index = None
        self._is_paused = None
        self._playlist_index = None
        self._playlist_length = None
        self._is_muted = None
        self._position_ticks = None
        self._run_time_ticks = None
        self._playback_start_time_ticks = None
        self._volume_level = None
        self._brightness = None
        self._aspect_ratio = None
        self._event_name = None
        self._play_method = None
        self._live_stream_id = None
        self._play_session_id = None
        self._repeat_mode = None
        self._shuffle = None
        self._subtitle_offset = None
        self._playback_rate = None
        self._playlist_item_ids = None
        self.discriminator = None
        if can_seek is not None:
            self.can_seek = can_seek
        if item is not None:
            self.item = item
        if now_playing_queue is not None:
            self.now_playing_queue = now_playing_queue
        if playlist_item_id is not None:
            self.playlist_item_id = playlist_item_id
        if item_id is not None:
            self.item_id = item_id
        if session_id is not None:
            self.session_id = session_id
        if media_source_id is not None:
            self.media_source_id = media_source_id
        if audio_stream_index is not None:
            self.audio_stream_index = audio_stream_index
        if subtitle_stream_index is not None:
            self.subtitle_stream_index = subtitle_stream_index
        if is_paused is not None:
            self.is_paused = is_paused
        if playlist_index is not None:
            self.playlist_index = playlist_index
        if playlist_length is not None:
            self.playlist_length = playlist_length
        if is_muted is not None:
            self.is_muted = is_muted
        if position_ticks is not None:
            self.position_ticks = position_ticks
        if run_time_ticks is not None:
            self.run_time_ticks = run_time_ticks
        if playback_start_time_ticks is not None:
            self.playback_start_time_ticks = playback_start_time_ticks
        if volume_level is not None:
            self.volume_level = volume_level
        if brightness is not None:
            self.brightness = brightness
        if aspect_ratio is not None:
            self.aspect_ratio = aspect_ratio
        if event_name is not None:
            self.event_name = event_name
        if play_method is not None:
            self.play_method = play_method
        if live_stream_id is not None:
            self.live_stream_id = live_stream_id
        if play_session_id is not None:
            self.play_session_id = play_session_id
        if repeat_mode is not None:
            self.repeat_mode = repeat_mode
        if shuffle is not None:
            self.shuffle = shuffle
        if subtitle_offset is not None:
            self.subtitle_offset = subtitle_offset
        if playback_rate is not None:
            self.playback_rate = playback_rate
        if playlist_item_ids is not None:
            self.playlist_item_ids = playlist_item_ids

    @property
    def can_seek(self):
        """Gets the can_seek of this PlaybackProgressInfo.  # noqa: E501

        A value indicating whether this instance can seek.  # noqa: E501

        :return: The can_seek of this PlaybackProgressInfo.  # noqa: E501
        :rtype: bool
        """
        return self._can_seek

    @can_seek.setter
    def can_seek(self, can_seek):
        """Sets the can_seek of this PlaybackProgressInfo.

        A value indicating whether this instance can seek.  # noqa: E501

        :param can_seek: The can_seek of this PlaybackProgressInfo.  # noqa: E501
        :type: bool
        """

        self._can_seek = can_seek

    @property
    def item(self):
        """Gets the item of this PlaybackProgressInfo.  # noqa: E501


        :return: The item of this PlaybackProgressInfo.  # noqa: E501
        :rtype: BaseItemDto
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this PlaybackProgressInfo.


        :param item: The item of this PlaybackProgressInfo.  # noqa: E501
        :type: BaseItemDto
        """

        self._item = item

    @property
    def now_playing_queue(self):
        """Gets the now_playing_queue of this PlaybackProgressInfo.  # noqa: E501


        :return: The now_playing_queue of this PlaybackProgressInfo.  # noqa: E501
        :rtype: list[QueueItem]
        """
        return self._now_playing_queue

    @now_playing_queue.setter
    def now_playing_queue(self, now_playing_queue):
        """Sets the now_playing_queue of this PlaybackProgressInfo.


        :param now_playing_queue: The now_playing_queue of this PlaybackProgressInfo.  # noqa: E501
        :type: list[QueueItem]
        """

        self._now_playing_queue = now_playing_queue

    @property
    def playlist_item_id(self):
        """Gets the playlist_item_id of this PlaybackProgressInfo.  # noqa: E501


        :return: The playlist_item_id of this PlaybackProgressInfo.  # noqa: E501
        :rtype: str
        """
        return self._playlist_item_id

    @playlist_item_id.setter
    def playlist_item_id(self, playlist_item_id):
        """Sets the playlist_item_id of this PlaybackProgressInfo.


        :param playlist_item_id: The playlist_item_id of this PlaybackProgressInfo.  # noqa: E501
        :type: str
        """

        self._playlist_item_id = playlist_item_id

    @property
    def item_id(self):
        """Gets the item_id of this PlaybackProgressInfo.  # noqa: E501

        The item identifier.  # noqa: E501

        :return: The item_id of this PlaybackProgressInfo.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this PlaybackProgressInfo.

        The item identifier.  # noqa: E501

        :param item_id: The item_id of this PlaybackProgressInfo.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def session_id(self):
        """Gets the session_id of this PlaybackProgressInfo.  # noqa: E501

        The session id.  # noqa: E501

        :return: The session_id of this PlaybackProgressInfo.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this PlaybackProgressInfo.

        The session id.  # noqa: E501

        :param session_id: The session_id of this PlaybackProgressInfo.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def media_source_id(self):
        """Gets the media_source_id of this PlaybackProgressInfo.  # noqa: E501

        The media version identifier.  # noqa: E501

        :return: The media_source_id of this PlaybackProgressInfo.  # noqa: E501
        :rtype: str
        """
        return self._media_source_id

    @media_source_id.setter
    def media_source_id(self, media_source_id):
        """Sets the media_source_id of this PlaybackProgressInfo.

        The media version identifier.  # noqa: E501

        :param media_source_id: The media_source_id of this PlaybackProgressInfo.  # noqa: E501
        :type: str
        """

        self._media_source_id = media_source_id

    @property
    def audio_stream_index(self):
        """Gets the audio_stream_index of this PlaybackProgressInfo.  # noqa: E501

        The index of the audio stream.  # noqa: E501

        :return: The audio_stream_index of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._audio_stream_index

    @audio_stream_index.setter
    def audio_stream_index(self, audio_stream_index):
        """Sets the audio_stream_index of this PlaybackProgressInfo.

        The index of the audio stream.  # noqa: E501

        :param audio_stream_index: The audio_stream_index of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._audio_stream_index = audio_stream_index

    @property
    def subtitle_stream_index(self):
        """Gets the subtitle_stream_index of this PlaybackProgressInfo.  # noqa: E501

        The index of the subtitle stream.  # noqa: E501

        :return: The subtitle_stream_index of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._subtitle_stream_index

    @subtitle_stream_index.setter
    def subtitle_stream_index(self, subtitle_stream_index):
        """Sets the subtitle_stream_index of this PlaybackProgressInfo.

        The index of the subtitle stream.  # noqa: E501

        :param subtitle_stream_index: The subtitle_stream_index of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._subtitle_stream_index = subtitle_stream_index

    @property
    def is_paused(self):
        """Gets the is_paused of this PlaybackProgressInfo.  # noqa: E501

        A value indicating whether this instance is paused.  # noqa: E501

        :return: The is_paused of this PlaybackProgressInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this PlaybackProgressInfo.

        A value indicating whether this instance is paused.  # noqa: E501

        :param is_paused: The is_paused of this PlaybackProgressInfo.  # noqa: E501
        :type: bool
        """

        self._is_paused = is_paused

    @property
    def playlist_index(self):
        """Gets the playlist_index of this PlaybackProgressInfo.  # noqa: E501


        :return: The playlist_index of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._playlist_index

    @playlist_index.setter
    def playlist_index(self, playlist_index):
        """Sets the playlist_index of this PlaybackProgressInfo.


        :param playlist_index: The playlist_index of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._playlist_index = playlist_index

    @property
    def playlist_length(self):
        """Gets the playlist_length of this PlaybackProgressInfo.  # noqa: E501


        :return: The playlist_length of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._playlist_length

    @playlist_length.setter
    def playlist_length(self, playlist_length):
        """Sets the playlist_length of this PlaybackProgressInfo.


        :param playlist_length: The playlist_length of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._playlist_length = playlist_length

    @property
    def is_muted(self):
        """Gets the is_muted of this PlaybackProgressInfo.  # noqa: E501

        A value indicating whether this instance is muted.  # noqa: E501

        :return: The is_muted of this PlaybackProgressInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_muted

    @is_muted.setter
    def is_muted(self, is_muted):
        """Sets the is_muted of this PlaybackProgressInfo.

        A value indicating whether this instance is muted.  # noqa: E501

        :param is_muted: The is_muted of this PlaybackProgressInfo.  # noqa: E501
        :type: bool
        """

        self._is_muted = is_muted

    @property
    def position_ticks(self):
        """Gets the position_ticks of this PlaybackProgressInfo.  # noqa: E501

        The position ticks.  # noqa: E501

        :return: The position_ticks of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._position_ticks

    @position_ticks.setter
    def position_ticks(self, position_ticks):
        """Sets the position_ticks of this PlaybackProgressInfo.

        The position ticks.  # noqa: E501

        :param position_ticks: The position_ticks of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._position_ticks = position_ticks

    @property
    def run_time_ticks(self):
        """Gets the run_time_ticks of this PlaybackProgressInfo.  # noqa: E501


        :return: The run_time_ticks of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._run_time_ticks

    @run_time_ticks.setter
    def run_time_ticks(self, run_time_ticks):
        """Sets the run_time_ticks of this PlaybackProgressInfo.


        :param run_time_ticks: The run_time_ticks of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._run_time_ticks = run_time_ticks

    @property
    def playback_start_time_ticks(self):
        """Gets the playback_start_time_ticks of this PlaybackProgressInfo.  # noqa: E501


        :return: The playback_start_time_ticks of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._playback_start_time_ticks

    @playback_start_time_ticks.setter
    def playback_start_time_ticks(self, playback_start_time_ticks):
        """Sets the playback_start_time_ticks of this PlaybackProgressInfo.


        :param playback_start_time_ticks: The playback_start_time_ticks of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._playback_start_time_ticks = playback_start_time_ticks

    @property
    def volume_level(self):
        """Gets the volume_level of this PlaybackProgressInfo.  # noqa: E501

        The volume level.  # noqa: E501

        :return: The volume_level of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._volume_level

    @volume_level.setter
    def volume_level(self, volume_level):
        """Sets the volume_level of this PlaybackProgressInfo.

        The volume level.  # noqa: E501

        :param volume_level: The volume_level of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._volume_level = volume_level

    @property
    def brightness(self):
        """Gets the brightness of this PlaybackProgressInfo.  # noqa: E501


        :return: The brightness of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._brightness

    @brightness.setter
    def brightness(self, brightness):
        """Sets the brightness of this PlaybackProgressInfo.


        :param brightness: The brightness of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._brightness = brightness

    @property
    def aspect_ratio(self):
        """Gets the aspect_ratio of this PlaybackProgressInfo.  # noqa: E501


        :return: The aspect_ratio of this PlaybackProgressInfo.  # noqa: E501
        :rtype: str
        """
        return self._aspect_ratio

    @aspect_ratio.setter
    def aspect_ratio(self, aspect_ratio):
        """Sets the aspect_ratio of this PlaybackProgressInfo.


        :param aspect_ratio: The aspect_ratio of this PlaybackProgressInfo.  # noqa: E501
        :type: str
        """

        self._aspect_ratio = aspect_ratio

    @property
    def event_name(self):
        """Gets the event_name of this PlaybackProgressInfo.  # noqa: E501


        :return: The event_name of this PlaybackProgressInfo.  # noqa: E501
        :rtype: ProgressEvent
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """Sets the event_name of this PlaybackProgressInfo.


        :param event_name: The event_name of this PlaybackProgressInfo.  # noqa: E501
        :type: ProgressEvent
        """

        self._event_name = event_name

    @property
    def play_method(self):
        """Gets the play_method of this PlaybackProgressInfo.  # noqa: E501


        :return: The play_method of this PlaybackProgressInfo.  # noqa: E501
        :rtype: PlayMethod
        """
        return self._play_method

    @play_method.setter
    def play_method(self, play_method):
        """Sets the play_method of this PlaybackProgressInfo.


        :param play_method: The play_method of this PlaybackProgressInfo.  # noqa: E501
        :type: PlayMethod
        """

        self._play_method = play_method

    @property
    def live_stream_id(self):
        """Gets the live_stream_id of this PlaybackProgressInfo.  # noqa: E501

        The live stream identifier.  # noqa: E501

        :return: The live_stream_id of this PlaybackProgressInfo.  # noqa: E501
        :rtype: str
        """
        return self._live_stream_id

    @live_stream_id.setter
    def live_stream_id(self, live_stream_id):
        """Sets the live_stream_id of this PlaybackProgressInfo.

        The live stream identifier.  # noqa: E501

        :param live_stream_id: The live_stream_id of this PlaybackProgressInfo.  # noqa: E501
        :type: str
        """

        self._live_stream_id = live_stream_id

    @property
    def play_session_id(self):
        """Gets the play_session_id of this PlaybackProgressInfo.  # noqa: E501

        The play session identifier.  # noqa: E501

        :return: The play_session_id of this PlaybackProgressInfo.  # noqa: E501
        :rtype: str
        """
        return self._play_session_id

    @play_session_id.setter
    def play_session_id(self, play_session_id):
        """Sets the play_session_id of this PlaybackProgressInfo.

        The play session identifier.  # noqa: E501

        :param play_session_id: The play_session_id of this PlaybackProgressInfo.  # noqa: E501
        :type: str
        """

        self._play_session_id = play_session_id

    @property
    def repeat_mode(self):
        """Gets the repeat_mode of this PlaybackProgressInfo.  # noqa: E501


        :return: The repeat_mode of this PlaybackProgressInfo.  # noqa: E501
        :rtype: RepeatMode
        """
        return self._repeat_mode

    @repeat_mode.setter
    def repeat_mode(self, repeat_mode):
        """Sets the repeat_mode of this PlaybackProgressInfo.


        :param repeat_mode: The repeat_mode of this PlaybackProgressInfo.  # noqa: E501
        :type: RepeatMode
        """

        self._repeat_mode = repeat_mode

    @property
    def shuffle(self):
        """Gets the shuffle of this PlaybackProgressInfo.  # noqa: E501


        :return: The shuffle of this PlaybackProgressInfo.  # noqa: E501
        :rtype: bool
        """
        return self._shuffle

    @shuffle.setter
    def shuffle(self, shuffle):
        """Sets the shuffle of this PlaybackProgressInfo.


        :param shuffle: The shuffle of this PlaybackProgressInfo.  # noqa: E501
        :type: bool
        """

        self._shuffle = shuffle

    @property
    def subtitle_offset(self):
        """Gets the subtitle_offset of this PlaybackProgressInfo.  # noqa: E501


        :return: The subtitle_offset of this PlaybackProgressInfo.  # noqa: E501
        :rtype: int
        """
        return self._subtitle_offset

    @subtitle_offset.setter
    def subtitle_offset(self, subtitle_offset):
        """Sets the subtitle_offset of this PlaybackProgressInfo.


        :param subtitle_offset: The subtitle_offset of this PlaybackProgressInfo.  # noqa: E501
        :type: int
        """

        self._subtitle_offset = subtitle_offset

    @property
    def playback_rate(self):
        """Gets the playback_rate of this PlaybackProgressInfo.  # noqa: E501


        :return: The playback_rate of this PlaybackProgressInfo.  # noqa: E501
        :rtype: float
        """
        return self._playback_rate

    @playback_rate.setter
    def playback_rate(self, playback_rate):
        """Sets the playback_rate of this PlaybackProgressInfo.


        :param playback_rate: The playback_rate of this PlaybackProgressInfo.  # noqa: E501
        :type: float
        """

        self._playback_rate = playback_rate

    @property
    def playlist_item_ids(self):
        """Gets the playlist_item_ids of this PlaybackProgressInfo.  # noqa: E501


        :return: The playlist_item_ids of this PlaybackProgressInfo.  # noqa: E501
        :rtype: list[str]
        """
        return self._playlist_item_ids

    @playlist_item_ids.setter
    def playlist_item_ids(self, playlist_item_ids):
        """Sets the playlist_item_ids of this PlaybackProgressInfo.


        :param playlist_item_ids: The playlist_item_ids of this PlaybackProgressInfo.  # noqa: E501
        :type: list[str]
        """

        self._playlist_item_ids = playlist_item_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlaybackProgressInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaybackProgressInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ClientCapabilities(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'playable_media_types': 'list[str]',
        'supported_commands': 'list[str]',
        'supports_media_control': 'bool',
        'push_token': 'str',
        'push_token_type': 'str',
        'supports_sync': 'bool',
        'device_profile': 'DeviceProfile',
        'icon_url': 'str',
        'app_id': 'str'
    }

    attribute_map = {
        'playable_media_types': 'PlayableMediaTypes',
        'supported_commands': 'SupportedCommands',
        'supports_media_control': 'SupportsMediaControl',
        'push_token': 'PushToken',
        'push_token_type': 'PushTokenType',
        'supports_sync': 'SupportsSync',
        'device_profile': 'DeviceProfile',
        'icon_url': 'IconUrl',
        'app_id': 'AppId'
    }

    def __init__(self, playable_media_types=None, supported_commands=None, supports_media_control=None, push_token=None, push_token_type=None, supports_sync=None, device_profile=None, icon_url=None, app_id=None):  # noqa: E501
        """ClientCapabilities - a model defined in Swagger"""  # noqa: E501
        self._playable_media_types = None
        self._supported_commands = None
        self._supports_media_control = None
        self._push_token = None
        self._push_token_type = None
        self._supports_sync = None
        self._device_profile = None
        self._icon_url = None
        self._app_id = None
        self.discriminator = None
        if playable_media_types is not None:
            self.playable_media_types = playable_media_types
        if supported_commands is not None:
            self.supported_commands = supported_commands
        if supports_media_control is not None:
            self.supports_media_control = supports_media_control
        if push_token is not None:
            self.push_token = push_token
        if push_token_type is not None:
            self.push_token_type = push_token_type
        if supports_sync is not None:
            self.supports_sync = supports_sync
        if device_profile is not None:
            self.device_profile = device_profile
        if icon_url is not None:
            self.icon_url = icon_url
        if app_id is not None:
            self.app_id = app_id

    @property
    def playable_media_types(self):
        """Gets the playable_media_types of this ClientCapabilities.  # noqa: E501


        :return: The playable_media_types of this ClientCapabilities.  # noqa: E501
        :rtype: list[str]
        """
        return self._playable_media_types

    @playable_media_types.setter
    def playable_media_types(self, playable_media_types):
        """Sets the playable_media_types of this ClientCapabilities.


        :param playable_media_types: The playable_media_types of this ClientCapabilities.  # noqa: E501
        :type: list[str]
        """

        self._playable_media_types = playable_media_types

    @property
    def supported_commands(self):
        """Gets the supported_commands of this ClientCapabilities.  # noqa: E501


        :return: The supported_commands of this ClientCapabilities.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_commands

    @supported_commands.setter
    def supported_commands(self, supported_commands):
        """Sets the supported_commands of this ClientCapabilities.


        :param supported_commands: The supported_commands of this ClientCapabilities.  # noqa: E501
        :type: list[str]
        """

        self._supported_commands = supported_commands

    @property
    def supports_media_control(self):
        """Gets the supports_media_control of this ClientCapabilities.  # noqa: E501


        :return: The supports_media_control of this ClientCapabilities.  # noqa: E501
        :rtype: bool
        """
        return self._supports_media_control

    @supports_media_control.setter
    def supports_media_control(self, supports_media_control):
        """Sets the supports_media_control of this ClientCapabilities.


        :param supports_media_control: The supports_media_control of this ClientCapabilities.  # noqa: E501
        :type: bool
        """

        self._supports_media_control = supports_media_control

    @property
    def push_token(self):
        """Gets the push_token of this ClientCapabilities.  # noqa: E501


        :return: The push_token of this ClientCapabilities.  # noqa: E501
        :rtype: str
        """
        return self._push_token

    @push_token.setter
    def push_token(self, push_token):
        """Sets the push_token of this ClientCapabilities.


        :param push_token: The push_token of this ClientCapabilities.  # noqa: E501
        :type: str
        """

        self._push_token = push_token

    @property
    def push_token_type(self):
        """Gets the push_token_type of this ClientCapabilities.  # noqa: E501


        :return: The push_token_type of this ClientCapabilities.  # noqa: E501
        :rtype: str
        """
        return self._push_token_type

    @push_token_type.setter
    def push_token_type(self, push_token_type):
        """Sets the push_token_type of this ClientCapabilities.


        :param push_token_type: The push_token_type of this ClientCapabilities.  # noqa: E501
        :type: str
        """

        self._push_token_type = push_token_type

    @property
    def supports_sync(self):
        """Gets the supports_sync of this ClientCapabilities.  # noqa: E501


        :return: The supports_sync of this ClientCapabilities.  # noqa: E501
        :rtype: bool
        """
        return self._supports_sync

    @supports_sync.setter
    def supports_sync(self, supports_sync):
        """Sets the supports_sync of this ClientCapabilities.


        :param supports_sync: The supports_sync of this ClientCapabilities.  # noqa: E501
        :type: bool
        """

        self._supports_sync = supports_sync

    @property
    def device_profile(self):
        """Gets the device_profile of this ClientCapabilities.  # noqa: E501


        :return: The device_profile of this ClientCapabilities.  # noqa: E501
        :rtype: DeviceProfile
        """
        return self._device_profile

    @device_profile.setter
    def device_profile(self, device_profile):
        """Sets the device_profile of this ClientCapabilities.


        :param device_profile: The device_profile of this ClientCapabilities.  # noqa: E501
        :type: DeviceProfile
        """

        self._device_profile = device_profile

    @property
    def icon_url(self):
        """Gets the icon_url of this ClientCapabilities.  # noqa: E501


        :return: The icon_url of this ClientCapabilities.  # noqa: E501
        :rtype: str
        """
        return self._icon_url

    @icon_url.setter
    def icon_url(self, icon_url):
        """Sets the icon_url of this ClientCapabilities.


        :param icon_url: The icon_url of this ClientCapabilities.  # noqa: E501
        :type: str
        """

        self._icon_url = icon_url

    @property
    def app_id(self):
        """Gets the app_id of this ClientCapabilities.  # noqa: E501


        :return: The app_id of this ClientCapabilities.  # noqa: E501
        :rtype: str
        """
        return self._app_id

    @app_id.setter
    def app_id(self, app_id):
        """Sets the app_id of this ClientCapabilities.


        :param app_id: The app_id of this ClientCapabilities.  # noqa: E501
        :type: str
        """

        self._app_id = app_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClientCapabilities, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClientCapabilities):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class ActivityLogEntry(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'overview': 'str',
        'short_overview': 'str',
        'type': 'str',
        'item_id': 'str',
        '_date': 'datetime',
        'user_id': 'str',
        'user_primary_image_tag': 'str',
        'severity': 'LoggingLogSeverity'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'overview': 'Overview',
        'short_overview': 'ShortOverview',
        'type': 'Type',
        'item_id': 'ItemId',
        '_date': 'Date',
        'user_id': 'UserId',
        'user_primary_image_tag': 'UserPrimaryImageTag',
        'severity': 'Severity'
    }

    def __init__(self, id=None, name=None, overview=None, short_overview=None, type=None, item_id=None, _date=None, user_id=None, user_primary_image_tag=None, severity=None):  # noqa: E501
        """ActivityLogEntry - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._overview = None
        self._short_overview = None
        self._type = None
        self._item_id = None
        self.__date = None
        self._user_id = None
        self._user_primary_image_tag = None
        self._severity = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if overview is not None:
            self.overview = overview
        if short_overview is not None:
            self.short_overview = short_overview
        if type is not None:
            self.type = type
        if item_id is not None:
            self.item_id = item_id
        if _date is not None:
            self._date = _date
        if user_id is not None:
            self.user_id = user_id
        if user_primary_image_tag is not None:
            self.user_primary_image_tag = user_primary_image_tag
        if severity is not None:
            self.severity = severity

    @property
    def id(self):
        """Gets the id of this ActivityLogEntry.  # noqa: E501

        The identifier.  # noqa: E501

        :return: The id of this ActivityLogEntry.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ActivityLogEntry.

        The identifier.  # noqa: E501

        :param id: The id of this ActivityLogEntry.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this ActivityLogEntry.  # noqa: E501

        The name.  # noqa: E501

        :return: The name of this ActivityLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ActivityLogEntry.

        The name.  # noqa: E501

        :param name: The name of this ActivityLogEntry.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def overview(self):
        """Gets the overview of this ActivityLogEntry.  # noqa: E501

        The overview.  # noqa: E501

        :return: The overview of this ActivityLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._overview

    @overview.setter
    def overview(self, overview):
        """Sets the overview of this ActivityLogEntry.

        The overview.  # noqa: E501

        :param overview: The overview of this ActivityLogEntry.  # noqa: E501
        :type: str
        """

        self._overview = overview

    @property
    def short_overview(self):
        """Gets the short_overview of this ActivityLogEntry.  # noqa: E501

        The short overview.  # noqa: E501

        :return: The short_overview of this ActivityLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._short_overview

    @short_overview.setter
    def short_overview(self, short_overview):
        """Sets the short_overview of this ActivityLogEntry.

        The short overview.  # noqa: E501

        :param short_overview: The short_overview of this ActivityLogEntry.  # noqa: E501
        :type: str
        """

        self._short_overview = short_overview

    @property
    def type(self):
        """Gets the type of this ActivityLogEntry.  # noqa: E501

        The type.  # noqa: E501

        :return: The type of this ActivityLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ActivityLogEntry.

        The type.  # noqa: E501

        :param type: The type of this ActivityLogEntry.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def item_id(self):
        """Gets the item_id of this ActivityLogEntry.  # noqa: E501

        The item identifier.  # noqa: E501

        :return: The item_id of this ActivityLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this ActivityLogEntry.

        The item identifier.  # noqa: E501

        :param item_id: The item_id of this ActivityLogEntry.  # noqa: E501
        :type: str
        """

        self._item_id = item_id

    @property
    def _date(self):
        """Gets the _date of this ActivityLogEntry.  # noqa: E501

        The date.  # noqa: E501

        :return: The _date of this ActivityLogEntry.  # noqa: E501
        :rtype: datetime
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this ActivityLogEntry.

        The date.  # noqa: E501

        :param _date: The _date of this ActivityLogEntry.  # noqa: E501
        :type: datetime
        """

        self.__date = _date

    @property
    def user_id(self):
        """Gets the user_id of this ActivityLogEntry.  # noqa: E501

        The user identifier.  # noqa: E501

        :return: The user_id of this ActivityLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ActivityLogEntry.

        The user identifier.  # noqa: E501

        :param user_id: The user_id of this ActivityLogEntry.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def user_primary_image_tag(self):
        """Gets the user_primary_image_tag of this ActivityLogEntry.  # noqa: E501

        The user primary image tag.  # noqa: E501

        :return: The user_primary_image_tag of this ActivityLogEntry.  # noqa: E501
        :rtype: str
        """
        return self._user_primary_image_tag

    @user_primary_image_tag.setter
    def user_primary_image_tag(self, user_primary_image_tag):
        """Sets the user_primary_image_tag of this ActivityLogEntry.

        The user primary image tag.  # noqa: E501

        :param user_primary_image_tag: The user_primary_image_tag of this ActivityLogEntry.  # noqa: E501
        :type: str
        """

        self._user_primary_image_tag = user_primary_image_tag

    @property
    def severity(self):
        """Gets the severity of this ActivityLogEntry.  # noqa: E501


        :return: The severity of this ActivityLogEntry.  # noqa: E501
        :rtype: LoggingLogSeverity
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this ActivityLogEntry.


        :param severity: The severity of this ActivityLogEntry.  # noqa: E501
        :type: LoggingLogSeverity
        """

        self._severity = severity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityLogEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityLogEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class LibraryAddMediaPath(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'path': 'str',
        'path_info': 'MediaPathInfo',
        'refresh_library': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'path': 'Path',
        'path_info': 'PathInfo',
        'refresh_library': 'RefreshLibrary'
    }

    def __init__(self, id=None, path=None, path_info=None, refresh_library=None):  # noqa: E501
        """LibraryAddMediaPath - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._path = None
        self._path_info = None
        self._refresh_library = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if path is not None:
            self.path = path
        if path_info is not None:
            self.path_info = path_info
        if refresh_library is not None:
            self.refresh_library = refresh_library

    @property
    def id(self):
        """Gets the id of this LibraryAddMediaPath.  # noqa: E501


        :return: The id of this LibraryAddMediaPath.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this LibraryAddMediaPath.


        :param id: The id of this LibraryAddMediaPath.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def path(self):
        """Gets the path of this LibraryAddMediaPath.  # noqa: E501


        :return: The path of this LibraryAddMediaPath.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this LibraryAddMediaPath.


        :param path: The path of this LibraryAddMediaPath.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def path_info(self):
        """Gets the path_info of this LibraryAddMediaPath.  # noqa: E501


        :return: The path_info of this LibraryAddMediaPath.  # noqa: E501
        :rtype: MediaPathInfo
        """
        return self._path_info

    @path_info.setter
    def path_info(self, path_info):
        """Sets the path_info of this LibraryAddMediaPath.


        :param path_info: The path_info of this LibraryAddMediaPath.  # noqa: E501
        :type: MediaPathInfo
        """

        self._path_info = path_info

    @property
    def refresh_library(self):
        """Gets the refresh_library of this LibraryAddMediaPath.  # noqa: E501


        :return: The refresh_library of this LibraryAddMediaPath.  # noqa: E501
        :rtype: bool
        """
        return self._refresh_library

    @refresh_library.setter
    def refresh_library(self, refresh_library):
        """Sets the refresh_library of this LibraryAddMediaPath.


        :param refresh_library: The refresh_library of this LibraryAddMediaPath.  # noqa: E501
        :type: bool
        """

        self._refresh_library = refresh_library

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(LibraryAddMediaPath, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LibraryAddMediaPath):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class MediaInfoServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_items_by_id_playbackinfo(self, id, user_id, **kwargs):  # noqa: E501
        """Gets live playback media info for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_items_by_id_playbackinfo(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :param str user_id: User Id (required)
        :return: PlaybackInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_items_by_id_playbackinfo_with_http_info(id, user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_items_by_id_playbackinfo_with_http_info(id, user_id, **kwargs)  # noqa: E501
            return data

    def get_items_by_id_playbackinfo_with_http_info(self, id, user_id, **kwargs):  # noqa: E501
        """Gets live playback media info for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_items_by_id_playbackinfo_with_http_info(id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :param str user_id: User Id (required)
        :return: PlaybackInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_items_by_id_playbackinfo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_items_by_id_playbackinfo`")  # noqa: E501
        # verify the required parameter 'user_id' is set
        if ('user_id' not in params or
                params['user_id'] is None):
            raise ValueError("Missing the required parameter `user_id` when calling `get_items_by_id_playbackinfo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/{Id}/PlaybackInfo', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlaybackInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_playback_bitratetest(self, size, **kwargs):  # noqa: E501
        """get_playback_bitratetest  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playback_bitratetest(size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int size: Size (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_playback_bitratetest_with_http_info(size, **kwargs)  # noqa: E501
        else:
            (data) = self.get_playback_bitratetest_with_http_info(size, **kwargs)  # noqa: E501
            return data

    def get_playback_bitratetest_with_http_info(self, size, **kwargs):  # noqa: E501
        """get_playback_bitratetest  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_playback_bitratetest_with_http_info(size, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int size: Size (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_playback_bitratetest" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'size' is set
        if ('size' not in params or
                params['size'] is None):
            raise ValueError("Missing the required parameter `size` when calling `get_playback_bitratetest`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'size' in params:
            query_params.append(('Size', params['size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Playback/BitrateTest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_by_id_playbackinfo(self, body, id, **kwargs):  # noqa: E501
        """Gets live playback media info for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_by_id_playbackinfo(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlaybackInfoRequest body: PlaybackInfoRequest:  (required)
        :param str id: (required)
        :return: PlaybackInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_by_id_playbackinfo_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_by_id_playbackinfo_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_items_by_id_playbackinfo_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Gets live playback media info for an item  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_by_id_playbackinfo_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param PlaybackInfoRequest body: PlaybackInfoRequest:  (required)
        :param str id: (required)
        :return: PlaybackInfoResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_by_id_playbackinfo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_by_id_playbackinfo`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_items_by_id_playbackinfo`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/{Id}/PlaybackInfo', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PlaybackInfoResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_livestreams_close(self, live_stream_id, **kwargs):  # noqa: E501
        """Closes a media source  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_livestreams_close(live_stream_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_stream_id: LiveStreamId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_livestreams_close_with_http_info(live_stream_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_livestreams_close_with_http_info(live_stream_id, **kwargs)  # noqa: E501
            return data

    def post_livestreams_close_with_http_info(self, live_stream_id, **kwargs):  # noqa: E501
        """Closes a media source  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_livestreams_close_with_http_info(live_stream_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_stream_id: LiveStreamId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['live_stream_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_livestreams_close" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'live_stream_id' is set
        if ('live_stream_id' not in params or
                params['live_stream_id'] is None):
            raise ValueError("Missing the required parameter `live_stream_id` when calling `post_livestreams_close`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'live_stream_id' in params:
            query_params.append(('LiveStreamId', params['live_stream_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveStreams/Close', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_livestreams_mediainfo(self, live_stream_id, **kwargs):  # noqa: E501
        """Closes a media source  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_livestreams_mediainfo(live_stream_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_stream_id: LiveStreamId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_livestreams_mediainfo_with_http_info(live_stream_id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_livestreams_mediainfo_with_http_info(live_stream_id, **kwargs)  # noqa: E501
            return data

    def post_livestreams_mediainfo_with_http_info(self, live_stream_id, **kwargs):  # noqa: E501
        """Closes a media source  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_livestreams_mediainfo_with_http_info(live_stream_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str live_stream_id: LiveStreamId (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['live_stream_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_livestreams_mediainfo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'live_stream_id' is set
        if ('live_stream_id' not in params or
                params['live_stream_id'] is None):
            raise ValueError("Missing the required parameter `live_stream_id` when calling `post_livestreams_mediainfo`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'live_stream_id' in params:
            query_params.append(('LiveStreamId', params['live_stream_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveStreams/MediaInfo', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_livestreams_open(self, body, **kwargs):  # noqa: E501
        """Opens a media source  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_livestreams_open(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LiveStreamRequest body: LiveStreamRequest:  (required)
        :return: LiveStreamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_livestreams_open_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_livestreams_open_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_livestreams_open_with_http_info(self, body, **kwargs):  # noqa: E501
        """Opens a media source  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_livestreams_open_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param LiveStreamRequest body: LiveStreamRequest:  (required)
        :return: LiveStreamResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_livestreams_open" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_livestreams_open`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/LiveStreams/Open', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='LiveStreamResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
